==> cocoa.macosx.x86-3.6-sources.jar: os_custom.h <==
/*******************************************************************************
 * Copyright (c) 2000, 2010 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

/* Libraries for dynamic loaded functions */
#define UnionRgn_LIB "com.apple.Carbon"
#define SetRect_LIB "com.apple.Carbon"
#define SectRgn_LIB "com.apple.Carbon"
#define RectRgn_LIB "com.apple.Carbon"
#define RectInRgn_LIB "com.apple.Carbon"
#define QDRegionToRects_LIB "com.apple.Carbon"
#define PtInRgn_LIB "com.apple.Carbon"
#define OpenRgn_LIB "com.apple.Carbon"
#define OffsetRgn_LIB "com.apple.Carbon"
#define NewRgn_LIB "com.apple.Carbon"
#define MoveTo_LIB "com.apple.Carbon"
#define LineTo_LIB "com.apple.Carbon"
#define GetRegionBounds_LIB "com.apple.Carbon"
#define EmptyRgn_LIB "com.apple.Carbon"
#define DisposeRgn_LIB "com.apple.Carbon"
#define DiffRgn_LIB "com.apple.Carbon"
#define CopyRgn_LIB "com.apple.Carbon"
#define CloseRgn_LIB "com.apple.Carbon"
#define instrumentObjcMessageSends_LIB "com.apple.Foundation"
#define SetThemeCursor_LIB "com.apple.Carbon"
#define GetCurrentButtonState_LIB "com.apple.Carbon"
#define GetDblTime_LIB "com.apple.Carbon"
#define CGContextCopyPath_LIB "com.apple.Cocoa"
#define TISCopyCurrentKeyboardInputSource_LIB "com.apple.Carbon"
#define TISGetInputSourceProperty_LIB "com.apple.Carbon"
#define UCKeyTranslate_LIB "com.apple.CoreServices"
#define kTISPropertyUnicodeKeyLayoutData_LIB "com.apple.Carbon"
#define ATSFontActivateFromFileReference_LIB "com.apple.ApplicationServices.ATS"
#define FSPathMakeRef_LIB "com.apple.CoreServices"
#define CGContextCopyWindowContentsToRect_LIB "com.apple.CoreGraphics"
#define LMGetKbdType_LIB "com.apple.Carbon"
#define GetThemeMetric_LIB "com.apple.Carbon"
#define HIThemeDrawFocusRect_LIB "com.apple.Carbon"
#define AcquireRootMenu_LIB "com.apple.Carbon"
#define CancelMenuTracking_LIB "com.apple.Carbon"
#define SetSystemUIMode_LIB "com.apple.Carbon"
#define GetSystemUIMode_LIB "com.apple.Carbon"
#define kTISPropertyUnicodeKeyLayoutData_LIB "com.apple.Carbon"
#define NSAccessibilityCellForColumnAndRowParameterizedAttribute_LIB "com.apple.Cocoa"
#define NSAccessibilityCellRole_LIB "com.apple.Cocoa"
#define NSAccessibilityColumnIndexRangeAttribute_LIB "com.apple.Cocoa"
#define NSAccessibilityRowIndexRangeAttribute_LIB "com.apple.Cocoa"

==> cocoa.macosx.x86-3.7-sources.jar: os_custom.h <==
/*******************************************************************************
 * Copyright (c) 2000, 2011 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

/* Libraries for dynamic loaded functions */
#define UnionRgn_LIB "com.apple.Carbon"
#define SetRect_LIB "com.apple.Carbon"
#define SectRgn_LIB "com.apple.Carbon"
#define RectRgn_LIB "com.apple.Carbon"
#define RectInRgn_LIB "com.apple.Carbon"
#define QDRegionToRects_LIB "com.apple.Carbon"
#define PtInRgn_LIB "com.apple.Carbon"
#define OpenRgn_LIB "com.apple.Carbon"
#define OffsetRgn_LIB "com.apple.Carbon"
#define NewRgn_LIB "com.apple.Carbon"
#define MoveTo_LIB "com.apple.Carbon"
#define LineTo_LIB "com.apple.Carbon"
#define GetRegionBounds_LIB "com.apple.Carbon"
#define EmptyRgn_LIB "com.apple.Carbon"
#define DisposeRgn_LIB "com.apple.Carbon"
#define DiffRgn_LIB "com.apple.Carbon"
#define CopyRgn_LIB "com.apple.Carbon"
#define CloseRgn_LIB "com.apple.Carbon"
#define FindWindow_LIB "com.apple.Carbon"
#define instrumentObjcMessageSends_LIB "com.apple.Foundation"
#define SetThemeCursor_LIB "com.apple.Carbon"
#define GetCurrentEventButtonState_LIB "com.apple.Carbon"
#define GetDblTime_LIB "com.apple.Carbon"
#define CGContextCopyPath_LIB "com.apple.Cocoa"
#define TISCopyCurrentKeyboardInputSource_LIB "com.apple.Carbon"
#define TISGetInputSourceProperty_LIB "com.apple.Carbon"
#define UCKeyTranslate_LIB "com.apple.CoreServices"
#define kTISPropertyUnicodeKeyLayoutData_LIB "com.apple.Carbon"
#define ATSFontActivateFromFileReference_LIB "com.apple.ApplicationServices.ATS"
#define FSPathMakeRef_LIB "com.apple.CoreServices"
#define CGContextCopyWindowContentsToRect_LIB "com.apple.CoreGraphics"
#define LMGetKbdType_LIB "com.apple.Carbon"
#define GetThemeMetric_LIB "com.apple.Carbon"
#define HIThemeDrawFocusRect_LIB "com.apple.Carbon"
#define AcquireRootMenu_LIB "com.apple.Carbon"
#define CancelMenuTracking_LIB "com.apple.Carbon"
#define SetSystemUIMode_LIB "com.apple.Carbon"
#define GetSystemUIMode_LIB "com.apple.Carbon"
#define kTISPropertyUnicodeKeyLayoutData_LIB "com.apple.Carbon"
#define NSAccessibilityCellForColumnAndRowParameterizedAttribute_LIB "com.apple.Cocoa"
#define NSAccessibilityCellRole_LIB "com.apple.Cocoa"
#define NSAccessibilityColumnIndexRangeAttribute_LIB "com.apple.Cocoa"
#define NSAccessibilityRowIndexRangeAttribute_LIB "com.apple.Cocoa"
#define GetIconRefFromTypeInfo_LIB "com.apple.LaunchServices"
#define GetIndMenuItemWithCommandID_LIB "com.apple.Carbon"
#define DeleteMenuItem_LIB "com.apple.Carbon"
#define PMSessionGetCurrentPrinter_LIB "com.apple.ApplicationServices"
#define PMSessionGetDestinationType_LIB "com.apple.ApplicationServices"
#define PMPrinterGetPrinterResolutionCount_LIB "com.apple.ApplicationServices"
#define PMPrinterGetOutputResolution_LIB "com.apple.ApplicationServices"
#define PMPrinterGetIndexedPrinterResolution_LIB "com.apple.ApplicationServices"
#define PMGetDuplex_LIB "com.apple.ApplicationServices"
#define PMSetDuplex_LIB "com.apple.ApplicationServices"
#define HIWindowFindAtLocation_LIB "com.apple.Carbon"
#define HIWindowGetCGWindowID_LIB "com.apple.Carbon"
